%define anolis_release 4
%global dirname_dict hunspell
%global upstream_version 2020.12.07
Name: hunspell-en
Summary: English hunspell dictionaries
Version: 0.%{upstream_version}
Release: %{anolis_release}%{?dist}
Source0: https://github.com/en-wl/wordlist/archive/rel-%{upstream_version}.tar.gz
Source1: http://download.services.openoffice.org/contrib/dictionaries/en_GB.zip
#See http://mxr.mozilla.org/mozilla/source/extensions/spellcheck/locales/en-US/hunspell/mozilla_words.diff?raw=1
Patch0: mozilla_words.patch
Patch1: en_GB-singleletters.patch
Patch2: en_GB.two_initial_caps.patch
#See https://github.com/en-wl/wordlist/issues/15
#filter removes words with "." in them
Patch3: en_US-strippedabbrevs.patch
#See https://sourceforge.net/p/hunspell/patches/35
#to allow "didn't" instead of suggesting change to typographical apostrophe
Patch4: hunspell-en-allow-non-typographical.marks.patch
#See https://bugzilla.redhat.com/show_bug.cgi?id=619577 add SI and IEC prefixes
Patch5: hunspell-en-SI_and_IEC.patch
#See https://github.com/en-wl/wordlist/issues/46 obscure Calender hides misspelling of Calendar
Patch6: hunspell-en-calender.patch
#valid English words that are archaic or rare in en-GB but not in en-IE
Patch7: en_IE.supplemental.patch
#call git to get the release hash, but this is a tarball
Patch8: hunspell-en-dont-call-git-during-build.patch
#rhbz#1492306 for better or worse treat etc the same in US and GB
Patch9: en_GB.etc.patch
Patch10: hunspell-en-buildfix.patch
URL: http://wordlist.sourceforge.net/
# README_en_GB.txt has specified just LGPL which mean LGPLv2+
# scowl/speller/aspell/en_affix.dat is BSD
# scowl/speller/aspell/en_phonet.dat is LGPLv2
License: LGPLv2+ and LGPLv2 and BSD

# Patches
Patch1001: 1001-build-optimization.patch
Patch1002: 1002-fix-warnings-while-building.patch 

BuildArch: noarch
BuildRequires: make, gcc-c++
BuildRequires: perl-Getopt-Long, perl-lib
BuildRequires: aspell, zip, dos2unix
Requires: hunspell-en-US = %{version}-%{release}
Requires: hunspell-en-GB = %{version}-%{release}
Requires: hunspell
Supplements: langpacks-en

%description
The English (US, UK, etc.) hunspell dictionaries

%package US
Requires: hunspell
Requires: hunspell-filesystem
Summary: hunspell US English dictionaries

%description US
hunspell US English dictionaries

%package GB
Requires: hunspell
Requires: hunspell-filesystem
Supplements: hunspell
Supplements: langpacks-en_GB
Summary: hunspell UK English dictionaries

%description GB
hunspell UK English dictionaries

%prep
%setup -q -n wordlist-rel-2020.12.07
%setup -q -a 1 -T -D -n wordlist-rel-2020.12.07
%patch -P 0 -p0 -b .mozilla
%patch -P 1 -p1 -b .singleletters
%patch -P 2 -p1 -b .two_initial_cap
%patch -P 3 -p0 -b .strippedabbrevs
%patch -P 4 -p0 -b .allow-non-typographical
%patch -P 5 -p0 -b .SI_and_IEC
%patch -P 6 -p1 -b .calender
%patch -P 7 -p1 -b .en_IE
%patch -P 8 -p1 -b .nogit
%patch -P 9 -p1 -b .etc
%patch -P 10 -p1 -b .buildfix
%patch1001 -p1
%patch1002 -p1

%build
export PERL5LIB=`pwd`/scowl/r/varcon${PERL5LIB:+:${PERL5LIB}}
make
cd scowl/speller
make hunspell
for i in README_en_CA.txt README_en_US.txt; do
  if ! iconv -f utf-8 -t utf-8 -o /dev/null $i > /dev/null 2>&1; then
    iconv -f ISO-8859-1 -t UTF-8 $i > $i.new
    touch -r $i $i.new
    mv -f $i.new $i
  fi
  tr -d '\r' < $i > $i.new
  touch -r $i $i.new
  mv -f $i.new $i
done

%install
mkdir -p $RPM_BUILD_ROOT/%{_datadir}/%{dirname_dict}
install -m 0644 -p en_??.dic en_??.aff $RPM_BUILD_ROOT/%{_datadir}/%{dirname_dict}
cd scowl/speller
install -m 0644 -p en_??.dic en_??.aff $RPM_BUILD_ROOT/%{_datadir}/%{dirname_dict}

pushd $RPM_BUILD_ROOT/%{_datadir}/%{dirname_dict}/
en_GB_aliases="en_AG en_BS en_BW en_BZ en_DK en_GH en_HK en_IE en_IN en_JM en_MW en_NA en_NG en_NZ en_SG en_TT en_ZA en_ZM en_ZW"
for lang in $en_GB_aliases; do
	ln -s en_GB.aff $lang.aff
	ln -s en_GB.dic $lang.dic
done
en_US_aliases="en_PH"
for lang in $en_US_aliases; do
	ln -s en_US.aff $lang.aff
	ln -s en_US.dic $lang.dic
done
popd

%files
%doc scowl/speller/README_en_CA.txt
%{_datadir}/%{dirname_dict}/*
%exclude %{_datadir}/%{dirname_dict}/en_GB.*
%exclude %{_datadir}/%{dirname_dict}/en_US.*

%files US
%doc scowl/speller/README_en_US.txt
%{_datadir}/%{dirname_dict}/en_US.*

%files GB
%doc README_en_GB.txt
%{_datadir}/%{dirname_dict}/en_GB.*

%changelog
* Wed Feb 19 2025 Xiaoping Liu <lxp01404969@linux.alibaba.com> - 0.2020.12.07-4
- Sync up from CentOS Stream hunspell-en-0.2020.12.07-11 (llfl@linux.alibaba.com)

* Sat Apr 8 2023 Kun(llfl) <llfl@linux.alibaba.com> - 0.2020.12.07-3
- optimize spec file

* Thu Mar 2 2023 Kun(llfl) <llfl@linux.alibaba.com> - 0.2020.12.07-2
- optimize spec file

* Tue Apr 12 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.2020.12.07-1
- init from upstream
